from typing import Any

def hook_re_module() -> None: ...

class EnabledHooks:
    def __init__(self) -> None: ...
    def add(self, hook: str) -> None: ...
    def __contains__(self, hook: str) -> bool: ...

enabled_hooks: EnabledHooks

# args[1] is an arbitrary string method that is called
# with the subsequent arguments, so they will vary
def _hook_str(*args: Any, **kwargs: Any) -> bool: ...
